@@ -78,12 +78,18 @@ BcdClockWidget::~BcdClockWidget(){
 }
 
 QSize BcdClockWidget::sizeHint(){
-    return QSize((((showSeconds) ? 6 : 4) * hoursOneWidget->getElementSize()) + (((showSeconds) ? 5 : 3) * layout->margin()),
-                 (4 * hoursOneWidget->getElementSize()) + (2 * layout->margin())
-#ifdef Q_WS_MAEMO_5
-                 + 6
-#endif
+    QSize size((((showSeconds) ? 6 : 4) * hoursOneWidget->getElementSize())
+                 + (((showSeconds) ? 5 : 3) * layout->spacing())
+                 + (2 * layout->margin()),
+                 (4 * hoursOneWidget->getElementSize())
+                 + (2 * layout->margin())
                  );
+#ifdef Q_WS_MAEMO_5
+    size.setHeight(size.height() + 10);
+    size.setWidth(size.width() + 50);
+#endif
+
+    return size;
 }
 
 void BcdClockWidget::updateTime(){
