@@ -60,12 +60,18 @@ BinaryClockWidget::~BinaryClockWidget(){
 }
 
 QSize BinaryClockWidget::sizeHint(){
-    return QSize((6 * (hoursWidget->getElementSize())) + (2 * layout->margin())
+    QSize size((6 * (hoursWidget->getElementSize()))
+                 + (2 * layout->margin()),
+                 (((showSeconds) ? 3 : 2) * hoursWidget->getElementSize())
+                 + (((showSeconds) ? 2 : 1) * layout->spacing())
+                 + (2 * layout->margin()));
+
 #ifdef Q_WS_MAEMO_5
-                 + 35
+    size.setHeight(size.height() + 10);
+    size.setWidth(size.width() + 40);
 #endif
-                 ,
-                 (((showSeconds) ? 3 : 2) * hoursWidget->getElementSize()) + (((showSeconds) ? 2 : 1) * layout->margin()) + 6);
+
+    return size;
 }
 
 void BinaryClockWidget::updateTime(){
