@@ -27,7 +27,7 @@ class HorizontalBinaryDisplayWidget : public BinaryDisplayWidget
     Q_OBJECT
 
 public:
-    explicit HorizontalBinaryDisplayWidget(int bits, int value, int height = 0, QWidget *parent = 0);
+    explicit HorizontalBinaryDisplayWidget(int bits, int value, int widgetSize = 0, QWidget *parent = 0);
 
     QSize sizeHint();
 
